Struct structbuf::Unpacker

source ·
#[repr(transparent)]
pub struct Unpacker<'a>(_);
Unpacker of POD values from a byte slice.

Any reads past the end of the slice return default values rather than panicking. The caller must check the error status at the end to determine whether all returned values were valid.

Little-endian encoding is assumed.

Implementations

Creates a new unpacker.

Returns the remaining byte slice or None if any reads went past the end of the original slice.

Returns the remaining number of bytes.

Returns whether the byte slice is empty.

Returns whether all reads were within the bounds of the original byte slice.

Returns the remaining byte slice in a new unpacker, leaving self empty. This is primarily useful in combination with map().

Returns Some output of f, or None if f fails to consume the entire slice without reading past the end.

Returns the output of f, or default if f fails to consume the entire slice without reading past the end.

Returns the output of f, or the output of default() if f fails to consume the entire slice without reading past the end.

Splits the remaining byte slice at i, and returns two new unpackers, both of which will be in an error state if len() < i.

Advances self by n bytes, returning a new unpacker for the skipped bytes or None if there is an insufficient number of bytes remaining, in which case any remaining bytes are discarded.

Examples
if let Some(mut hdr) = p.skip(2) {
    let _ = hdr.u16();
    assert!(hdr.is_ok() && p.is_ok());
} else {
    assert!(!p.is_ok());
}

Returns the next u8 as a bool where any non-zero value is converted to true.

Returns the next u8.

Returns the next u16.

Returns the next u32.

Returns the next u64.

Returns the next u128.

Returns the next i8.

Returns the next i16.

Returns the next i32.

Returns the next i64.

Returns the next i128.

Returns the next T, or T::default() if there is an insufficient number of bytes remaining, in which case any remaining bytes are discarded.

Safety

T must be able to hold the resulting bit pattern.