Trait structbuf::Unpack

source ·
pub trait Unpack {
    fn unpack(&self) -> Unpacker<'_>;
}
Trait for getting an unpacker for a byte slice.

Required Methods

Returns an unpacker for reading values from the start of the buffer.

Implementors

Blanket implementation for all AsRef<[u8]> types.