pub trait Unpack { fn unpack(&self) -> Unpacker<'_>; }
Trait for getting an unpacker for a byte slice.
Returns an unpacker for reading values from the start of the buffer.
Blanket implementation for all AsRef<[u8]> types.
AsRef<[u8]>